@@ -133,7 +133,7 @@ exportReports.redcapApiConnection <- function(rcon, report_id, factors = TRUE, l
   
   if (x$status_code != 200) redcap_error(x, error_handling)
   
-  x <- utils::read.csv(textConnection(as.character(x)), 
+  x <- utils::read.csv(text = as.character(x), 
                        stringsAsFactors = FALSE, 
                        na.strings = "")
 
